<?php

/*
 * Plugin Name: wp pear debug
 * Description: Integration of pear php_debug. Plugin discussion forum: http://www.communitymodder.com/Wordpress-Plugins/88-wp-pear-debug-wordpress-plugin.html
 * Author: Community Modder
 * Plugin URI: http://www.communitymodder.com
 * Version: 1.4
 * =======================================================================
 */


//Step into plugin class to initialize
add_action('plugins_loaded',array('wp_pear_debug','init'));

//wordpress plugin completely wrapped in class
class wp_pear_debug
{

	//Option states
	const WPD_STATUS_DISABLE = 0;
	const WPD_STATUS_FRONT = 1;
	const WPD_STATUS_ADMIN = 2;
	const WPD_STATUS_BOTH = 3;
	//general status
	const WPD_ENABLE = 1;
	const WPD_DISABLE = 0;
	const WPD_PREFIX = 'wp_pear_debug_';
	
	//Script names
	const WPD_JS = 'wp_pear_debug_js';
	const WPD_CSS = 'wp_pear_debug_css';
	
	
	
	//Definitions
	const WPD_GUEST_ROLE = 'guest';	
	const WPD_STATUS = 'status';
	
	//shortcut for getting and setting distinct option name						 
	protected static function opt($suffix)
	{
		return self::WPD_PREFIX.$suffix;
	}
	
	//return the path to the plugin fold
	private static function path()
	{
		return WP_PLUGIN_DIR.'/wp-pear-debug';
	}
	//return the path to the plugin via wordpress url
	private static function url()
	{
		return WP_PLUGIN_URL.'/wp-pear-debug';
	}
		
	//include javascript
	public static function js()
	{ 
		wp_enqueue_script(self::WPD_JS); 
	}
	//include css
	public static function css()
	{
		wp_enqueue_style(self::WPD_CSS); 
	}
	//Configuration options for debug library
	//These really should not change for wordpress needs
	public static function getConf()
	{
		return array
		(
			'render_type'          => 'HTML',
			'render_mode'          => 'Div',
			'restrict_access'      => false,
			'allow_url_access'     => false,
			'enable_watch'         => false,
			'replace_errorhandler' => true,
			'HTML_DIV_images_path' => self::url()."/images",
		);
	}	
	//include a class file
	//neat way of loading classes relative to base folder
	public static function loadClass($sClassPath)
	{
		$aParts = explode(".",$sClassPath);
		$sFile = self::path()."/";
		$iCount = 0;
		
		foreach($aParts as $sPart )
		{
			if( $iCount != count($aParts)-1 )
			{
				$sFile.= $sPart."/";
			}	
			else
			{			
				$sFile.= $sPart.".class.php";
				
				break;
					
			}			
			$iCount++;
		}
		
		if( file_exists($sFile) && !is_dir($sFile) )
		{
			include_once($sFile);
		}
		else
		{
			throw new Exception($sFile);
			
		}
	
	}
	//return instance of class
	public static function getClass($sClassPath)
	{
		self::loadClass($sClassPath);
		
		$aParts = explode(".",$sClassPath);
		$sClass = $aParts[count($aParts)-1];
		$oClass =  new $sClass;
		//Use exisiting instance if possible
		if(method_exists($oClass,'singleton'))
		{
			$oClass = $oClass->singleton();
			
		}
	
		return $oClass;
		
	}
	
	//Class initialization
	public static function init()
	{
		//Load config and determine debug level for current user
		$sDebug = self::enabled();
	
	
		if($sDebug)
		{
			//register javascript
			wp_register_script(self::WPD_JS, "".self::url()."/js/html_div.js"); 
			//register css
			wp_register_style(self::WPD_CSS, "".self::url()."/css/html_div.css");
			 		
			//Include debug output for admin
			if($sDebug == self::WPD_STATUS_ADMIN || $sDebug == self::WPD_STATUS_BOTH)
			{ 
				add_action('admin_print_scripts',array('wp_pear_debug','js'));
				add_action('admin_print_styles',array('wp_pear_debug','css'));
				add_action('admin_footer',array('wp_pear_debug','show'));
			}
			//Include debug output for front end
			if( $sDebug == self::WPD_STATUS_FRONT || $sDebug == self::WPD_STATUS_BOTH )
			{ 
				add_action('wp_print_styles',array('wp_pear_debug','css'));
				add_action('wp_print_scripts',array('wp_pear_debug','js'));
				add_action('wp_footer',array('wp_pear_debug','show'));
			}		

			//unlimited possibilities for add_filter and this plugin
			add_filter('query',array('wp_pear_debug','query'));
			//Enable shortcode debug entry point
			add_shortcode('wp_pear_debug', array('wp_pear_debug','short'));
		}
		//add options page to the admin menu
		add_action('admin_menu',array('wp_pear_debug','admin'));
	}
	//not using globals
	//use this to get single instance of debug class
	//All this drama just to load one class library!
	public static function get()
	{	
		//return current instance of the pear debug class	
		return self::getClass('PHP_Debug');
	}
	
	public static function show()
	{
		//Get current instance of debug class
		$oDebug = self::get();
		//Display debug information
		$oDebug->display();
	}
	
	//add database query to debug
	public static function query($query)
	{
		//Get current instance of debug class
		$oDebug = self::get();
		//Add sql query to debug output
		$oDebug->query($query);
		//Pass back out from wordpress filter
		return $query;
	}
	
	protected static function enabled()
	{

		//Got rid of switch
		//Read options if the plugin is enabled
		/******
		Get option automatically creates options that are non existent
		Therefore the initial state of the plugin will be the desired effect where all options are disabled
		Hence the absence of an installer
		******/
		if( get_option( self::opt( self::WPD_STATUS) ) == self::WPD_ENABLE )
		{
			//Attempt to load the current user
			$u = wp_get_current_user();
			//Get current user role
			if( is_array($u->roles) && count($u->roles) )
			{
				$role = array_shift( $u->roles );
			}
			else
			{
				//Can't obtain role so user must be guest
				$role = self::WPD_GUEST_ROLE;
			}
				
			//load option for user role
			if(  is_numeric(get_option(self::opt($role)))  )
			{
				
				return get_option(self::opt($role));
			
			}
		
		}
		else
		{
			return false;
		}
		

				
	}

		//wrapper functions
		//Library contains more functionality but these are essentials
		
		public static function add($sVar)
		{
			$oDebug = self::get();
			$oDebug->add($sVar);
			
		}
		public static function dump($obj, $varName = '')
		{
			$oDebug = self::get();
			$oDebug->dump($obj, $varName);
			
		}	
		public static function queryRel($sInfo)
		{
			$oDebug = self::get();
			$oDebug->queryRel($sInfo);
			
		}
		public static function error($sInfo)
		{
			$oDebug = self::get();
			$oDebug->error($sInfo);
			
		}
		//shortcode entry point to debug
		//Does not return anything
		//Picks up data from post content
		//Have no idea what this can be used for! lol!
		public static function short($atts,$sContent='')
		{
			
			if( isset($sContent) && !empty($sContent) )
			{
				self::add($sContent);
			}
			else
			{
				self::dump($atts);
			}
		}	

//Add in admin options with link under settings "Debugger"
public static function admin() 
{

	add_options_page('Debugger Options', 'Debugger', 10, '/wp-pear-debug/'.basename(__FILE__),array('wp_pear_debug','options'));
 }


public static function options()
{
	global $wpdb;

	?>
<div class=wrap>
  <form method="post" action="options.php">
  <?php wp_nonce_field('update-options'); ?>

    <h3>Debugger Settings</h3>
<div>
<div class="postbox">



<select name="<?php echo self::opt(self::WPD_STATUS);?>">
<option value="<?php echo self::WPD_DISABLE;?>" <?php  if( get_option(self::opt(self::WPD_STATUS))== self::WPD_DISABLE ) echo "selected"; ?> >Disable Debugging</option>
<option  value="<?php echo self::WPD_ENABLE;?>" <?php  if( get_option(self::opt(self::WPD_STATUS))== self::WPD_ENABLE ) echo "selected"; ?> >Enable Debugging</option>
</select>


</div>
<h3> Display Debug for Roles:</h3>
<div class="postbox">
<table>
<tr>
<td  >

 <strong>Guests</strong>
</td>
<td>
<select name="<?php echo self::opt(self::WPD_GUEST_ROLE); ?>">
<option value="<?php echo self::WPD_STATUS_DISABLE;?>" <?php  if(get_option(self::opt(self::WPD_GUEST_ROLE)) == self::WPD_STATUS_DISABLE) echo "selected"; ?> >Disable</option>
<option  value="<?php echo self::WPD_STATUS_FRONT;?>" <?php  if(get_option(self::opt(self::WPD_GUEST_ROLE)) == self::WPD_STATUS_FRONT) echo "selected"; ?> >Front End Only</option>
</select>
</td>
</tr>
<?php 
$sKeys = self::opt(self::WPD_GUEST_ROLE).",".self::opt(self::WPD_STATUS);
foreach(get_option($wpdb->prefix . 'user_roles')  as $key => $value)
{
	//define the role key for options
	$role_opt = self::opt($key);
	?>
	<tr>
	<td>
<strong><?php echo ucfirst($key); ?></strong>	
</td>
<td>
<select name="<?php echo $role_opt ?>">	
<option value="<?php echo self::WPD_STATUS_DISABLE;?>" <?php  if(get_option($role_opt)== self::WPD_STATUS_DISABLE) echo "selected"; ?> >Disable</option>	
<option value="<?php echo self::WPD_STATUS_FRONT;?>" <?php  if(get_option($role_opt)== self::WPD_STATUS_FRONT) echo "selected"; ?> >Front End Only</option>	
<option value="<?php echo self::WPD_STATUS_ADMIN;?>" <?php  if(get_option($role_opt)== self::WPD_STATUS_ADMIN) echo "selected"; ?> >Admin Only</option>	
<option value="<?php echo self::WPD_STATUS_BOTH;?>" <?php  if(get_option($role_opt)== self::WPD_STATUS_BOTH) echo "selected"; ?> >Admin & Front End</option>	
</select>	
<?php
$sKeys.=','.$role_opt."";
}
?>
</td>
</tr>
</table>
</div>
<input type="hidden" name="action" value="update" />
<input type="hidden" name="page_options" value="<?php echo $sKeys; ?>" />

</div>
<div class="submit">
<input type="submit" name="Submit" value="<?php _e('Save Changes') ?>" />
</div>

  </form>
 </div>

 <?php
}

	
	
}	






?>